import React, { useCallback, useEffect, useMemo, useRef, useState, forwardRef, useImperativeHandle } from 'react';
import { AudioOutlined } from '@ant-design/icons';
import {
  Row,
  DatePicker,
  Select,
  Button,
  Input,
  Tooltip,
  Space,
  Popconfirm,
  message,
  Upload,
  ConfigProvider,
  Modal,
  Image,
  Dropdown,
  Menu,
  Popover,
  Form,
} from 'antd';

import 'dayjs/locale/zh-cn';
import locale from 'antd/es/date-picker/locale/zh_CN';

import {
  SnippetsOutlined,
  PlusOutlined,
  FormOutlined,
  DeleteOutlined,
  ImportOutlined,
  ExportOutlined,
  FileZipOutlined,
  FileImageOutlined,
  CustomerServiceOutlined,
  VideoCameraOutlined,
  ExclamationCircleOutlined,
  QuestionCircleOutlined,
  EditOutlined,
  DownOutlined,
} from '@ant-design/icons';
import styles from './search.less';
import moment from 'moment';
const { Search } = Input;
const { RangePicker } = DatePicker;
const { Option } = Select;
const dateFormat = 'YYYY-MM-DD';

const SearchGroup = forwardRef((props, ref) => {

  useImperativeHandle(ref, () => ({
    getQueryInfo,
  }));
  const { readOnly } = props
  const [form] = Form.useForm();

  const [showPicker, setShowPicker] = useState(true);
  const [dateArray, setDateArray] = useState([
    // moment(moment().format('YYYY-MM-DD 00:00:00')).subtract(1, 'years'),
    // moment(moment().format('YYYY-MM-DD 23:59:59')),
  ]);
  const [formatterStr, setFormatterStr] = useState('YYYY-MM-DD HH:mm:ss');
  const [searchValues, setSearchValues] = useState('');
  // const [queryWheres, setQueryWheres] = useState([
  //   props.params.tempQueryWhere || {},
  // ])
  const [queryWheres, setQueryWheres] = useState([{}]);
  const [searchKey, setSearchKey] = useState(''); // 快速搜索字段名称
  const [queryInfo, setQueryInfo] = useState({ info: '', timeFrom: '', timeTo: '' });

  const rangerOptions = useMemo(() => {
    const todayRanger = [
      moment(moment().format(`${dateFormat} 00:00:00`)),
      moment(moment().format(`${dateFormat} 23:59:59`)),
    ];
    const yesterdayRanger = [
      moment(
        moment()
          .subtract(1, 'days')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(
        moment()
          .subtract(1, 'days')
          .format(`${dateFormat} 23:59:59`),
      ),
    ];
    const currentWeekRanger = [
      moment(
        moment()
          .startOf('week')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(
        moment()
          .endOf('week')
          .format(`${dateFormat} 23:59:59`),
      ),
    ];
    const lastWeekRanger = [
      moment(
        moment()
          .subtract(1, 'week')
          .startOf('week')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(
        moment()
          .subtract(1, 'week')
          .endOf('week')
          .format(`${dateFormat} 23:59:59`),
      ),
    ];
    const lastMonthRanger = [
      moment(
        moment()
          .subtract(1, 'month')
          .startOf('month')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(
        moment()
          .subtract(1, 'month')
          .endOf('month')
          .format(`${dateFormat} 23:59:59`),
      ),
    ];
    const currentMonthRanger = [
      moment(
        moment()
          .startOf('month')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(
        moment()
          .endOf('month')
          .format(`${dateFormat} 23:59:59`),
      ),
    ];
    const last30DaysRanger = [
      moment(
        moment()
          .subtract(30, 'days')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(moment().format(`${dateFormat} 23:59:59`)),
    ];
    const lastOneYearRanger = [
      moment(
        moment()
          .subtract(1, 'years')
          .format(`${dateFormat} 00:00:00`),
      ),
      moment(moment().format(`${dateFormat} 23:59:59`)),
    ];
    return {
      昨天: yesterdayRanger,
      今天: todayRanger,
      本周: currentWeekRanger,
      上周: lastWeekRanger,
      本月: currentMonthRanger,
      上月: lastMonthRanger,
      近30天: last30DaysRanger,
      近一年: lastOneYearRanger,
    };
  }, []);
  const dateChange = (dateObj, dateString) => {
    setDateArray(dateObj || ['', '']);
    setQueryInfo({
      ...queryInfo,
      timeFrom: dateObj[0].format('YYYY-MM-DD HH:mm:ss') || '',
      timeTo: dateObj[1].format('YYYY-MM-DD HH:mm:ss') || '',
    });
  };
  const onSearch = e => {
    // if (fieldSearch) {
    //   setQueryWheres([{
    //     "field": searchKey,
    //     "value": e,
    //     "type": "模糊查询"
    //   }])
    // } else {
    //   getAccountData();
    // }
    setQueryInfo({ ...queryInfo, info: e });
    getQueryInfo(form.getFieldsValue());
  };

  const onValuesChange = values => {
    let keys = Object.keys(values);
    if (keys.includes('info')) return;
    getQueryInfo(form.getFieldsValue());
  };

  const getQueryInfo = data => {
    let params = {};
    params.timeFrom = (data.time && data.time[0].format('YYYY-MM-DD HH:mm:ss')) || '';
    params.timeTo = (data.time && data.time[1].format('YYYY-MM-DD HH:mm:ss')) || '';
    params.info = data.info;
    props && props.onChange(params);
    return params;
  };

  const reset = () => {
    form.resetFields()
    btnsClick('重置')
  }

  const btnsClick = type => {
    props?.btnsClick?.(type, null);
  };

  return (
    <Row className={styles.controlRow}>
      <Form layout={'inline'} form={form} onValuesChange={onValuesChange}>
        {
          showPicker ? (
            <Form.Item label={`录入时间`} name="time" style={{ marginBottom: 0 }}>
              <RangePicker
                size="middle"
                value={[...dateArray]}
                locale={locale}
                // defaultValue={rangerOptions[timeQuantumStr]}
                showTime={formatterStr === 'YYYY-MM-DD HH:mm:ss'}
                ranges={{ ...rangerOptions }}
                format={formatterStr}
                style={{ width: 300 }}
              // onChange={dateChange}
              />
            </Form.Item>
          ) : null
        }
        <Form.Item label={'快捷搜索'} name="info" style={{ marginBottom: 0 }}>
          <Search
            size="middle"
            style={{
              width: 320,
              verticalAlign: 'middle',
              marginLeft: '10px',
            }}
            placeholder="请输入值"
            onSearch={onSearch}
          />
        </Form.Item>
        <Form.Item style={{ marginBottom: 0 }}>
          <Button type="primary" onClick={() => reset()}>
            重置
          </Button>
        </Form.Item>
      </Form>
      {/* 按钮区域 */}
      <div className={styles.controlRowRight}>
        <div className={styles.controlBtns}>
          {
            !readOnly ? (
              <Button
                type="primary"
                size="middle"
                onClick={() => btnsClick('添加')}
                icon={<PlusOutlined />}
                style={{ marginLeft: 20 }}
              >
                添加
              </Button>
            ) : null
          }
        </div>
      </div>
    </Row>
  )
})

export default SearchGroup
