import React, { useEffect, useMemo, useState } from 'react'
import styles from './index.less'
import { Button, Upload, message } from 'antd'
import { accepts, getFileType } from '../../../../../../constant'
import { uploadFileUrl, downloadFileUrl, downloadFile } from '../../../../../../apis/process'
import {
  SnippetsOutlined,
  PlusOutlined,
  FormOutlined,
  DeleteOutlined,
  ImportOutlined,
  ExportOutlined,
  FileZipOutlined,
  FileImageOutlined,
  CustomerServiceOutlined,
  VideoCameraOutlined,
  ExclamationCircleOutlined,
  QuestionCircleOutlined,
  EditOutlined,
  DownOutlined,
  FileOutlined,
  UploadOutlined,
  ArrowDownOutlined
} from '@ant-design/icons'
import FileViewer from 'react-file-viewer'
import Viewer from 'viewerjs-react'
import Drag from '../../../../../components/Drag'

const FileView = (props) => {
  const site = window.globalConfig?.userInfo?.site || window.globalConfig?.userInfo?.LocalSite
  const { value, fileType, title, preview, download } = props
  let fileList = value ? value.split(',') : []
  const [visible, setVisible] = useState(false)
  const [viewVisible, setViewVisible] = useState(false)
  const [showFile, setShowFile] = useState({ fileType: '', filePath: '' })

  const showList = useMemo(() => {
    let list = []
    fileList.forEach((item, index) => {
      if (item) { // @Tips: 直接过滤掉名字中有异常字符的文件
        let uid = index + '_' + Math.random()
        let _obj = {
          uid: uid,
          value: item,
          name: item.split('\\').reverse()[0],
          type: fileType === '图片' ? 'image/jpeg' : 'file',
          status: 'done',
          url: `${downloadFileUrl}?filePath=${item}${site ? `&_site=${site}` : ''}`,
          sourcePath: item.url,
          originFileObj: { "uid": uid },
          "response": { "code": 0, "msg": "Ok", "data": item, "stackTrace": null },
          "xhr": {},
        };
        // if (schema.renderTo === 'Image') _obj.thumbUrl = `${downloadFileUrl}?filePath=${item}${site ? `&_site=${site}` : ''}`;
        list.push(_obj)
      }
    })
    return JSON.stringify(list)
  }, [value])

  if (!fileList.length) return null

  if (fileType === '图片') {
    return (
      <div className={styles.fileView}>
        <Viewer>
          {
            fileList.map((v, i) => {
              return (
                <span className={styles.imgSpan} key={v} style={{ display: i == 0 ? 'inline-block' : 'none' }}>
                  {fileList.length !== 1 ? <span className={styles.imgSub}>{fileList.length}</span> : null}
                  <img
                    className={styles.img}
                    src={`${window.origin}/PandaWorkFlow/WorkFlow/AccountManage/DownloadFiles?filePath=${v}`}
                  >
                  </img>
                </span>
              )
            })
          }
        </Viewer>
      </div>
    )
  }

  const iconRender = (file, listType) => {
    if (listType !== 'text') {
      let fileType = getFileType(file.name)
      if (fileType) {
        return <div className={styles.iconImg} type={fileType}></div>
      } else {
        return <div className={styles.iconImg} type={'通用'}></div>
      }
    }
    return <FileOutlined />
  }

  const option = {
    name: 'file',
    // action: `${window.location.origin}${uploadFileUrl}`,
    listType: 'picture',
    withCredentials: true,
    showUploadList: download ?
      {
        showDownloadIcon: '下载',
        downloadIcon: <ArrowDownOutlined style={{ color: fileType === '图片' ? 'white' : '' }} />,
        showRemoveIcon: false
      } : { showRemoveIcon: false },
    onPreview: (file) => {
      if (!preview) return message.info('该附件禁止预览')
      let fileType = getFileType(file.name)
      if (fileType) {
        setShowFile({ name: file.name, fileType: fileType, filePath: file.url })
        setViewVisible(true)
      }
    }
  }

  return (
    <div className={styles.fileView}>
      <Button
        size='small'
        icon={<FileZipOutlined />}
        onClick={() => setVisible(true)}
      >
        {fileList.length}条记录
      </Button>
      <Drag
        onOk={() => setVisible(false)}
        onCancel={() => setVisible(false)}
        title={title}
        visible={visible}
      >
        <Upload
          // disabled={disabled}
          // accept={accepts[fileType]}
          fileList={showList ? JSON.parse(showList) : []}
          className="upload-list-inline"
          iconRender={iconRender}
          {...option}
        />
      </Drag>
      <Drag
        width={'70%'}
        title={showFile.name}
        visible={viewVisible}
        onCancel={() => setViewVisible(false)}
        onOk={() => setViewVisible(false)}
        bodyStyle={{ height: 650, overflowY: showFile.fileType.includes('xlsx') ? 'none' : "auto" }}
      >
        <FileViewer
          className='fileViewer'
          title='123'
          fileType={showFile.fileType}
          filePath={window.location.origin + showFile.filePath}
        />
      </Drag>
    </div>
  )

}

export default FileView