import React, { useMemo } from 'react'
import styles from './index.less'
import { isObject } from '../../../../utils'

const PrintXform = (props) => {

  const { schemaForm, form } = props

  const formTable = useMemo(() => {
    const { column, properties } = schemaForm
    let hiddenFields = Object.keys(form.getHiddenValues()).map(v => v?.split('.')?.[1])
    let formValue = {}
    Object.keys(form.formData).map(v => {
      if (isObject(form.formData[v])) {
        Object.keys(form.formData[v]).forEach(s => {
          formValue[s] = form.formData[v][s]
        })
      }
    })
    let array = []
    Object.keys(properties).map(v => {
      let childObj = properties[v]?.properties || {}
      let child = []
      let num = 0
      Object.keys(childObj).forEach(s => {
        if (!hiddenFields.includes(s)) {
          let width = childObj[s].width || ((100 / column).toFixed(2) + '%')
          if (width !== '100%') {
            num++
          }
          child.push({
            title: childObj[s].title,
            fieldName: s,
            fieldValue: formValue[s],
            width: width,
            labelWidth: childObj[s].labelWidth || 120
          })
        }
      })
      if (num % column !== 0 && child[child.length - 1] !== '100%') {
        child[child.length - 1].width = ((100 / column) * (column + 1 - num % column)).toFixed(2) + '%'
      }
      array.push({
        title: properties[v].title,
        fieldName: v,
        fieldValue: null,
        child,
      })
    })
    return array
  }, [schemaForm, form])

  return (
    <div className={styles.printXform}>
      {
        formTable.map(v => {
          return (
            <div className={styles.printGroup} key={v.fieldName}>
              <div className={styles.groupName}>{v.title}</div>
              <div className={styles.boxs}>
                {
                  v.child.map(s => {
                    return (
                      <div key={s.fieldName} className={styles.box} style={{ width: s.width }}>
                        <div className={styles.itemLeft} style={{ width: s.labelWidth }}>{s.title}</div>
                        <div className={styles.itemRight}>{s.fieldValue}</div>
                      </div>
                    )
                  })
                }
              </div>
            </div>
          )
        })
      }
    </div>
  )

}

export default PrintXform